Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1872)

Unified Diff: runtime/observatory/lib/src/models/objects/thread.dart

Issue 2762323002: Reimplemented zone memory tracking to avoid race conditions that were causing crashes in the previo… (Closed)
Patch Set: Final change Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/observatory/lib/src/models/objects/thread.dart
diff --git a/runtime/observatory/lib/src/models/objects/thread.dart b/runtime/observatory/lib/src/models/objects/thread.dart
index 7bff72c9191eb98a34a8a0a5a15c7741dee29909..be461fdf4845fe97653cee7ceab584f38cdf5fde 100644
--- a/runtime/observatory/lib/src/models/objects/thread.dart
+++ b/runtime/observatory/lib/src/models/objects/thread.dart
@@ -20,10 +20,10 @@ abstract class Thread {
/// The task type associated with the thread.
ThreadKind get kind;
- /// The maximum amount of memory in bytes allocated by a thread at a given
- /// time throughout the entire life of the thread.
- int get memoryHighWatermark;
+ /// The maximum amount of zone memory in bytes allocated by a thread at a
+ /// given time throughout the entire life of the thread.
+ int get zoneHighWatermark;
- /// A list of all the zones held by the thread.
- Iterable<Zone> get zones;
+ /// The current Zone capacity available to this thread.
+ int get zoneCapacity;
}
« no previous file with comments | « runtime/observatory/lib/src/models/objects/isolate.dart ('k') | runtime/observatory/lib/src/service/object.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698